@@ -1,4 +1,65 @@
 #!/bin/bash
+
+# ---------------------- actionAndComponentUsingViewerExtension.xml ----------------------
+# Example taken from distributed source ./sdk/libraries/cepcoreschema/testdata/actionAndComponentUsingViewerExtension.xml
+cat <<EOF > actionAndComponentUsingViewerExtension.xml
+<?xml version="1.0" encoding="UTF-8" standalone="no" ?>
+<cep xmlns="http://camitk.imag.fr/cepcoreschema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://camitk.imag.fr/cepcoreschema Cep.xsd">
+  <name>A CEP with one action and one component that required a viewer extension</name>
+  <contact>
+    <email>Emmanuel.Promayon@univ-grenoble-alpes.fr</email>
+  </contact>
+  <description>This CEP contains a new type of component and an action that can do something with it where both require the medicalimageviewer viewer extension.
+This test the link between an action and a component defined in the same CEP as well as the dependency to a viewer.</description>
+  <actionExtensions>
+    <actionExtension>
+      <name>Test Actions</name>
+      <description>This extension description is really useless.</description>
+      <actions>
+        <action>
+          <name>Test Action</name>
+          <description>This description is void.</description>
+          <component>TestMeshBasedComponent</component>
+          <classification>
+            <family>Testing CepGenerator</family>
+          </classification>
+          <parameters>
+            <parameter defaultValue="100.0" description="Testing double" editable="true" name="testDouble" type="double" unit=""/>
+          </parameters>
+        </action>
+      </actions>
+      <dependencies>
+        <dependency name="testcomponents" type="component"/>
+        <dependency name="medicalimageviewer" type="viewer"/>
+      </dependencies>
+    </actionExtension>
+  </actionExtensions>
+  <componentExtensions>
+    <componentExtension>
+      <name>Test components</name>
+      <description>This extension description a new / specific component</description>
+      <components>
+        <component>
+          <name>TestMeshBasedComponent</name>
+          <description>My description is useless...</description>
+          <representation>Mesh</representation>
+          <properties>
+            <parameter defaultValue="false" description="Testing bools" editable="true" name="testBool" type="bool" unit=""/>
+            <parameter defaultValue="QColor(255, 255, 255, 255)" description="Testing color" editable="true" name="testColor" type="QColor" unit=""/>
+            <parameter defaultValue="QVector3D(0.0, 0.0, 0.0)" description="test 3D vector" editable="true" name="testVector3D" type="QVector3D" unit=""/>
+          </properties>
+          <fileSuffix>specific</fileSuffix>
+        </component>
+        <dependencies>
+          <dependency name="medicalimageviewer" type="viewer"/>
+        </dependencies>
+      </components>
+    </componentExtension>
+  </componentExtensions>
+</cep>
+EOF
+
+
 # ---------------------- exampleComponents.xml ----------------------
 # Example taken from distributed source ./sdk/libraries/cepcoreschema/testdata/exampleComponents.xml
 cat <<EOF > exampleComponents.xml
@@ -15,7 +76,7 @@ cat <<EOF > exampleComponents.xml
     <copyright><![CDATA[/* ****************************************************************************
 $USERDEF_LICENCE_BEGIN$
 CamiTK - Computer Assisted Medical Intervention ToolKit
-(c) 2001-2018 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+(c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
         
 Visit http://camitk.imag.fr for more information
         
@@ -122,7 +183,7 @@ cat <<EOF > actionsExamplesLicence.xml
     <copyright><![CDATA[/*****************************************************************************
 $USERDEF_LICENCE_BEGIN$
 CamiTK - Computer Assisted Medical Intervention ToolKit
-(c) 2001-2018 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+(c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
         
 Visit http://camitk.imag.fr for more information
         
@@ -369,7 +430,7 @@ cat <<EOF > completeTest1.xml
   <copyright><![CDATA[/*****************************************************************************
 $USERDEF_LICENCE_BEGIN$
 CamiTK - Computer Assisted Medical Intervention ToolKit
-(c) 2001-2018 Univ. Grenoble Alpes, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
+(c) 2001-2021 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
         
 Visit http://camitk.imag.fr for more information
         
@@ -523,9 +584,62 @@ $USERDEF_LICENCE_END$
       <dependencies>
         <dependency type="library" name="XSD"/>
         <dependency type="library" name="ITK"/>
-        <dependency type="cepLibrary" name="qtpropertybrowser"/>
+        <!-- remove due to cmake error
+             CMake Error at /usr/share/camitk-5.0/cmake/macros/camitk/CamiTKLibrary.cmake:412 (add_dependencies):
+               The dependency target "library-qtpropertybrowser" of target
+               "library-testlib" does not exist.
+             Call Stack (most recent call first):
+               libraries/testlib/CMakeLists.txt:6 (camitk_library)
+
+             The case of dependency to CEPLIBRARY build in CamiTK CE/ CamiTKCore  outside CAMITK_COMMUNITY_EDITION_BUILD should be
+             taken into account for recent CMake versions
+             <dependency type="cepLibrary" name="qtpropertybrowser"/>
+         -->
       </dependencies>
     </library>
   </libraries>
 </cep>
 EOF
+
+
+# ---------------------- viewerExample.xml ----------------------
+# Example taken from distributed source ./sdk/libraries/cepcoreschema/testdata/viewerExample.xml
+cat <<EOF > viewerExample.xml
+<?xml version="1.0" encoding="UTF-8"?>
+<cep xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
+     xmlns="http://camitk.imag.fr/cepcoreschema"
+     xsi:schemaLocation="http://camitk.imag.fr/cepcoreschema ../cep.xsd">
+    <name>Test Viewer CEP</name>
+    <contact>
+        <email>Emmanuel.Promayon@univ-grenoble-alpes.fr</email> 
+    </contact>
+    <description>Example of a CEP with two viewer extensions</description>
+    <viewerExtensions>
+        <viewerExtension>
+            <name>Test Viewer 1</name>
+            <description>This viewer extension manages a default viewer</description>
+            <registerDefaultViewer/>
+            <viewer>
+                <name>Test Viewer 1</name>
+                <description>Example of simple embedded viewer</description>
+                <type>EMBEDDED</type>
+                <component>MeshComponent</component>
+                <component>ImageComponent</component>
+            </viewer>           
+        </viewerExtension>
+        
+        <viewerExtension>
+            <name>Test Viewer 2</name>
+            <description>This viewer extension manages three named viewer</description>
+            <registerNewViewer>First Test Viewer</registerNewViewer>
+            <registerNewViewer>Second Test Viewer</registerNewViewer>
+            <viewer>
+                <name>Test Viewer 2</name>
+                <description>Example of simple docked viewer</description>
+                <type>DOCKED</type>
+                <component>Component</component>
+            </viewer>   
+        </viewerExtension>
+    </viewerExtensions>
+</cep>
+EOF
